<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>Fejl i config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>Fejl under kørsel af plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>Filen kunne ikke loades.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>Ugyldigt filformat.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>Filen kunne ikke gemmes.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>Følgende XML kunne ikke fortolkes:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>Encodingen blev ikke genkendt.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>Manglende svar på linje:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>Det var ikke muligt at åbne databasen.
Opretter tmp fil.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>Fil eksisterer:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;Overskriv</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>Fjernede dubletter:</translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>Der er kort med forskellige svar til spørgsmål:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Flet og rediger</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;Flet ikke</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>Færdig!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Du kan ikke huske dette kort endnu.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Som &apos;0&apos;, men det er ved at blive genkendeligt.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished">Vis det sjældnere.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Du husker dette kort nu,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished">og vil nok huske det et par dage.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Du har fuldstændig glemt dette kort.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Langt fra korrekt svar. Intervallet var alt for langt.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Rigtigt svar, men med meget besvær.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished">Intervallet var nok lidt for langt.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Rigtigt svar, men med noget besvær.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished">Intervallet var nok rigtigt.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Rigtigt svar, men uden noget</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished">besvær. Intervallet var nok lidt for kort.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Hovedforfatter: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>Mere info: http://mnemosyne-proj.org
</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Aktiver kategorier</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Vælg de kategorier der skal aktiveres:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Aktiver ingen</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Aktiver alle</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standard&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Drop dette kort?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørgsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Skreven form:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Oversættelse:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Kortet er allerede i databasen.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Dublet blev ikke tilføjet.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Der er forskellige svar til</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation>dette spørgsmål:</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Flet og rediger</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Tiløj som det er</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Tilføj ikke</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Tilføj kort</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørgsmål:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Udtalelse:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Tilføj &amp;vice versa også</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Vælg startgrad:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Du husker ikke dette kort endnu eller har glemt det.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Som &apos;0&apos;, men det er ved at blive genkendeligt.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Du husker dette kort nu, og vil nok huske det et par dage.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Rigtigt svar, men med meget besvær. Intervallet var nok for langt</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Rigtigt svar, med noget besvær. Intervallet var nok rigtigt.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Rigtigt svar, men uden noget besvær. Intervallet var nok for kort.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Indtast spørgsmål og svar, og vælg så startgrad.</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Af&amp;slut</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+S</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Skift kategori</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+A</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemosyne konfiguration</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Hold markøren over knapperne for at få ekstra information.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Udseende</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Vælg Spørgsmål/Svar skrifttype</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Vælg skrifttypen der bruges når der vises enkelte spørgsmål og svar</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Vælg listeskrifttype</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Vælg skrifttypen der bruges til visning af en liste over alle kort i et sæt</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Forøg størrelsen af ikke-latinske tegn med</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Komplekse symboler og tegn være svære at læse med standard latin skriftstørrelse</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>point</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Log upload</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Upload anonyme logs</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Del anonyme statistikker for at hjælpe hukommelsesforskning</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Dublet behandling</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Tjek for dubletter når der tilføjes nye kort</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Tillad dubletter i forskellige kategorier</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Repetitionsproces</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation>Antal kort af grad 0 på en gang:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Note: dette er IKKE antallet af grad 0-kort du vil lære *pr. dag*</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation>Lær nye kort i tilfældig rækkefølge</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Standarder</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Rediger kort</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørgsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Forhåndsvisning</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+A</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Vent venligst...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Forhåndsvisning</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;Tilføj vice versa</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>S&amp;tatistik</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slet</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>S&amp;kift kategori</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Tilføj &amp;vice versa</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Tilføj vice versa til disse kort?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Tilføj vice versa til dette kort?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Dette kan medføre dubletter hvis vice</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>versa allerede er lavet,
så du vil sikkert gerne køre</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>fjern dubletter bagefter.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Grad:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Lethed:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Repetitioner:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Omgange:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Dage siden sidste repetition:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dage før næste repetition:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Slet disse kort?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Slet dette kort?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>Teksten blev ikke fundet.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>F&amp;ind igen</translation>
    </message>
    <message>
        <source>F</source>
        <translation>i</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>F&amp;ind</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Svar</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Rediger sæt</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>F&amp;ind</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Højreklik på et kort for at redigere det.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Af&amp;slut</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+S</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle Filer (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Eksporter til fil</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Filformat:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Eksporter til fil:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Gennemse</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Kategorier til eksportering:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Vælg alle</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Nulstil indlæringsdata ved eksport</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standard&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle Filer (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Importer fra fil-</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Filformat:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Importer fra fil:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Gennemse</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Læg kort uden kategori i denne kategori:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Note: alle kort bliver tilføjet til den nuværende database.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Nulstil indlæringsdata ved import</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished">Mnemosyne databaser (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Ny</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">Vent venligst...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished">Slet dette kort?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Nej</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished">Vender tilbage om </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished"> dag(e).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished">Næste repetition: i dag.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished">Næste repetition: i morgen.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished">Næste repetition om </translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> dage.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Spørgsmål:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;standard&gt;</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Vis svar</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished">Lær forud for skema</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished">Vælg antal dage før næste repetition:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">Angiv grad for dit svar:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished">Planlagt: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished">Ikke memoriseret: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished">Alle: </translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørgsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Vis svar</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Angiv grad for dit svar:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Åben...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+Å</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Gem &amp;Som...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Afs&amp;lut</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Tilføj kort</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Tilføj kort</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Aktiver kate&amp;gorier</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Rediger sæt</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Re&amp;diger sæt</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Import</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Vis &amp;værktøjslinje</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Rediger dette kort</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Rediger dette kort</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Slet dette kort</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Slet dette kort</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Fjern dubletter</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Konfigurer Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Kom igang</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Kom igang</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Ned, Ned</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mellemrum</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Vis statistik</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Vis s&amp;tatistik</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Dagens tip</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>Dagens &amp;/tip</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Hovedværktøjslinje (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Sæt</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Indstillinger</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standard&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørgsmål:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Forhåndsvis kort</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørgsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Kom igang</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Velkommen!

Jeg er Mnemosyne, en slags sommerfugl navngivet efter den græske hukommelsesgudinde.

Jeg kan gøre det mere effektivt for dig at memorisere og huske svar på spørgsmål, ved at hjælpe dig med at fokusere på de kort de oftest glemmer, og ved ikke at spilde din tid på ting du husker godt.

For at gøre det, vil jeg vælge hvilke spørgsmål der skal stilles hvornår, og du skal så give dem en grad efter hvor godt du huskede svarene.

Lad os se på betydningen af graderne nu.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Introduktion</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Graderne går fra 0 til 5.

Graderne 0 og 1 bruges, hvis du endnu ikke kender svaret, eller hvis du har glemt det. Et kort med graden 1 er ved at være mere genkendeligt end et med grad 0, og vil derfor blive gentaget sjældnere.

Jeg vil blive ved med at stille dig disse spørgsmål indtil du giver dem en grad på 2 eller højere (den eksakte grad betyder ikke noget). Grad 2 er de kort du tror du vil huske mindst et par dage. Den signalerer overgangen mellem kort- og langtidshukommelse.

Jeg vil planlægge dette kort en dag i fremtiden, hvor jeg regner med du stadig vil kunne huske det med lidt besvær, uden at have glemt det fuldstændig. Det er den mest effektive måde at lære på, i det tidsrum hvor man har en smule besvær med at genkalde svaret.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Graderne 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Hvis jeg stiller dig spørgsmål for tidligt, og du husker dem uden problemer, sætter du kortets grad til 5. Jeg vil så huske dette og vente lidt længere før jeg stiller spørgsmålet igen.

Hvis jeg rammer lige plet, så du husker det, men dog med lidt besvær, bruges grad 4.

Hvis du på den anden side har for meget besvær med at huske svaret, og du mener jeg har ventet for łænge med at stille spørgsmålet, så sætter du graden til 3.

Hvis du har glemt det fuldstændig, kan du sætte graden tilbage til enten 0 eller 1, og jeg vil blive ved med at stille dette spørgsmål indtil du mener, at du kan huske det i et par dage igen.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Graderne 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Hvis du godt kan lide statistik, kan jeg lave en detaljeret log over din gennemgange.

Men ikke blot det, jeg kan også uploade en fuldstændig anonym version af disse logs til en central side for analyser, so du kan hjælpe med at gøre mig bedre. På den måde hjælper du også videnskabelig forskning inden for langtidshukommelse.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Upload anonyme logs</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Du kan altid ændre denne indstilling senere i &apos;Konfigurer Mnemosyne&apos; menuen.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Nu er du klar til at starte!
&lt;p&gt;
Tilføj nye kort ved at klikke på ikonet med &apos;plus&apos;-tegnet i øverste venstre hjørne.
&lt;p&gt;
Husk, du skal ikke bekymre dig om at gemme dit arbejde, jeg gør det helt automatisk.
&lt;p&gt;
For de bedste resultater, anbefaler jeg at du foretager gennemgange hver dag. Jeg vil dog gøre mit bedste for at håndtere det selvom du skulle komme bagud, eller har lyst til at lære lidt forud for planen.
&lt;p&gt;
Se mere dokumentation på http://www.mnemosyne-proj.sourceforge.net (engelsk).
&lt;p&gt;
God fornøjelse!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Klar til start</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Indsæt &amp;billede</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Indsæt &amp;lyd</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;3-sidet input</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Billedfiler</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Indsæt billede</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Indsæt lyd</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation>Planlagte kort for den næste uge:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>dag(e) : </translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Antal kort med følgende grader:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Grad</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation>Ingen kort.</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Grad:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Lethed:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Repetitioner:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Omgange:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Dage siden sidste repetition:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dage før næste repetition:</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Plan</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Grader</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation>Dette kort</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>For at opnå optimale resultater, er det bedst at repetere hver dag.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Du skal ikke bekymre dig hvis du har været væk et par dage. Gennemgå så mange kort du har lyst til for at indhente det, resten vil automatisk blive genplanlagte.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>Indstillingen &apos;antal kort af grad 0 på en gang&apos; bestemmer hvor mange nye kort du prøver på at lære på en gang. Den fortæller dig &lt;b&gt;ikke&lt;/b&gt; hvor mange nye kort du skal lære hver dag. Du bestemmer hvor mange du vil lære, nogle dage flere andre dage færre alt efter hvad du har lyst til.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Altså, prøv at gennemgå dine repetitioner hver dag, men du skal ikke bekymre dig for meget om at få &apos;planlagte&apos;-tælleren ned på 0, og slet ikke om at få &apos;Ikke memoriseret&apos;-tælleren ned på 0.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Grad 1 kort er forskellige fra grad 0 kort, idet de ikke bliver vist så ofte og ikke er genstand for indstillingen &apos;antal kort af grad 0 på en gang&apos;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Du kan bruge genvejstaster til at gennemgå dine repetitioner. Enter, Return eller Mellemrum giver standard-handlingen (&apos;Vis svar&apos; eller &apos;grad 4&apos;). Taltasterne kan bruges til at vælge grader.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Du kan vælge kategorier du har lyst til at studer i menuen &apos;Aktiver kategorier&apos;.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Det anbefales at du putter alle dine kort i en database og bruger kategorier til at organisere dem. At bruge &apos;Aktiver kategorier&apos; er langt bedre end at skulle loade forskellige databaser hele tiden.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Du kan importere kort fra en bred vifte af formater: txt-filer med tab-afgrænsning, Supermemo filer, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Hvis du har kort i Word eller Excel, kan du eksportere dem til UTF-8 unicode encodede txt-filer, hvor spørgsmål og svar er delt med tab, for at kunne importere dem til Mnemosyne.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Hvis du har lyst til at printe dine kort ud, kan du eksportere dem til en txt-fil, som du så kan printe ud fra din yndlingsteksteditor.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Du kan dele kort med andre ved at eksportere dem til XML og vælge indstillingen &apos;Nulstil indlæringsdata&apos; ved eksport.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Hvis du studerer et fremmedsprog med en anden type skrift, kan standardskriftstørrelsen nogle gange være en smule lille. Hvis du vil gøre størrelsen af disse tegn større, men beholde størrelsen på den danske tekst, kan du bruge indstillingen &apos;Forøg størrelsen af ikke-latinske tegn med X point&apos;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Du kan tilføje billeder og lyd til dine kort. Højreklik på spørgsmål- eller svarfeltet når du redigerer et kort, for at få en pop-up-menu frem til dette.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Det anbefales at du har dine lyd- og billedfiler i din .mnemosyne-folder. På den måde er det lettere at flytte dine data mellem forskellige computere.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Når du tilføjer 3-sidede kort, vil der blive lavet to egentlige kort. Et med den skrevne form som spørgsmål, og et svar med udtale og betydning, og det andet med betydningen som spørgsmål og et svar med den skrevne form og udtalen.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Du kan bruge basale HTML-tags i dine kort for at kontrollere udseendet.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne kan bruge LaTeX for at udskrive matematiske formler, fx &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (Du skal have LaTeX og dvipng installeret for denne funktion.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>Den bedste måde at tage en backup af dine data er ved at kopiere din .mnemosyne-folder (hvis du følger den anbefalede procedure, at beholde alle dine filer der) og flytte dem til et andet drev. Mnemosyne tager automatisk XML-baserede backups i .mnemosyne/backups, men det hjælper ikke noget hvis drevet dør... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Du kan køre Mnemosyne fra en USB-nøgle. Kopier C:\Programmer\Mnemosyne til din USB-nøgle, og kopier så .mnemosyne-folderen fra din hjemmefolder ind i Mnemosyne-folderen på din USB-nøgle.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Hvis du bruger Mnemosyne på flere computere er der en smart værktøj kaldet Unison, der kan hjælpe dig med at synkronisere data. Se Mnemosyne hjemmesiden for mere information.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Du kan sortere kortene i &apos;Rediger Sæt&apos; dialogen efter svar eller efter kategori ved at klikke på kolonnetitlerne. Ved et efterfølgende klik vil sorteringensordning omvendes.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Hvis du vil have mere kontrol over LaTeX&apos;s opførsel, kan du se nærmere forklaring af &lt;$$&gt;...&lt;/$$&gt; og &lt;latex&gt;...&lt;/latex&gt;-taggene på Mnemosynes hjemmeside.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Avancerede brugere kan tilpasse mere af Mnemosyne ved at redigere filen config.py i deres .mnemosyne-folder. Der kan også installeres plugins for at tilpasse Mnemosyne endnu mere.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Dagens tip</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Vidste du at...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Vis tips ved opstart</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>F&amp;orrige</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Næste</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+L</translation>
    </message>
</context>
</TS>
